==> community-profile-api-1.1-sources.jar: org/odpi/openmetadata/accessservices/communityprofile/properties/WatchStatus.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.communityprofile.properties;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.io.Serializable;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * WatchStatus specifies whether changes to assets in an asset collection should be
 * passed as notifications to the actor who's profile is linked to the collection.
 * <ul>
 *     <li>NOT_WATCHED - Notifications should not be sent to the actor.</li>
 *     <li>WATCHED - Notifications should be sent to the actor.</li>
 *     <li>USE_DEFAULT - Use the default setting for the collection to determine whether to send notifications.</li>
 * </ul>
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public enum WatchStatus implements Serializable
{
    NOT_WATCHED     (0,  "Not Watched", "Notifications should not be sent to the actor."),
    WATCHED         (1,  "Watched",     "Notifications should be sent to the actor."),
    USE_DEFAULT     (99, "Use Default", "Use the default setting for the collection to determine whether to send notifications.");

    private static final long serialVersionUID = 1L;

    private int            ordinal;
    private String         name;
    private String         description;


    /**
     * Default constructor for the enumeration.
     *
     * @param ordinal numerical representation of the enumeration
     * @param name default string name of the enumeration
     * @param description default string description of the enumeration
     */
    WatchStatus(int  ordinal, String name, String description)
    {
        this.ordinal = ordinal;
        this.name = name;
        this.description = description;
    }


    /**
     * Return the numeric representation of the enumeration.
     *
     * @return int ordinal
     */
    public int getOrdinal() { return ordinal; }


    /**
     * Return the default name of the enumeration.
     *
     * @return String name
     */
    public String getName() { return name; }


    /**
     * Return the default description of the enumeration.
     *
     * @return String description
     */
    public String getDescription() { return description; }


    /**
     * toString() JSON-style
     *
     * @return string description
     */
    @Override
    public String toString()
    {
        return "WatchStatus : " + name;
    }
}

==> community-profile-api-3.6-sources.jar: org/odpi/openmetadata/accessservices/communityprofile/properties/WatchStatus.java <==
/* SPDX-License-Identifier: Apache-2.0 */
/* Copyright Contributors to the ODPi Egeria project. */
package org.odpi.openmetadata.accessservices.communityprofile.properties;

import com.fasterxml.jackson.annotation.JsonAutoDetect;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonInclude;

import java.io.Serializable;

import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.NONE;
import static com.fasterxml.jackson.annotation.JsonAutoDetect.Visibility.PUBLIC_ONLY;

/**
 * WatchStatus specifies whether changes to assets in an asset collection should be
 * passed as notifications to the actor who's profile is linked to the collection.
 * <ul>
 *     <li>NOT_WATCHED - Notifications should not be sent to the actor.</li>
 *     <li>WATCHED - Notifications should be sent to the actor.</li>
 *     <li>USE_DEFAULT - Use the default setting for the collection to determine whether to send notifications.</li>
 * </ul>
 */
@JsonAutoDetect(getterVisibility=PUBLIC_ONLY, setterVisibility=PUBLIC_ONLY, fieldVisibility=NONE)
@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(ignoreUnknown=true)
public enum WatchStatus implements Serializable
{
    NOT_WATCHED     (0,  "Not Watched", "Notifications should not be sent to the actor."),
    WATCHED         (1,  "Watched",     "Notifications should be sent to the actor."),
    USE_DEFAULT     (99, "Use Default", "Use the default setting for the collection to determine whether to send notifications.");

    private static final long serialVersionUID = 1L;

    private final int            ordinal;
    private final String         name;
    private final String         description;


    /**
     * Default constructor for the enumeration.
     *
     * @param ordinal numerical representation of the enumeration
     * @param name default string name of the enumeration
     * @param description default string description of the enumeration
     */
    WatchStatus(int  ordinal, String name, String description)
    {
        this.ordinal = ordinal;
        this.name = name;
        this.description = description;
    }


    /**
     * Return the numeric representation of the enumeration.
     *
     * @return int ordinal
     */
    public int getOrdinal() { return ordinal; }


    /**
     * Return the default name of the enumeration.
     *
     * @return String name
     */
    public String getName() { return name; }


    /**
     * Return the default description of the enumeration.
     *
     * @return String description
     */
    public String getDescription() { return description; }


    /**
     * toString() JSON-style
     *
     * @return string description
     */
    @Override
    public String toString()
    {
        return "WatchStatus : " + name;
    }
}
